import * as Discord from 'discord.js';
import {log} from '../core/utils';
import {PAGE_NAME_REGEXP} from '../models/wikidot-page';
import transferPage from './pages-transferer';
import axios from 'axios';

const vega = new Discord.Client();
const token = process.env.DISCORD_BOT_TOKEN;

const COMMAND_REGEXP = /^[\/!](\w+)/;
const DEV_CHANNEL_ID = '402913158127288321';
const STAFF_CHANNEL_ID = '363739114895441921';
const MEMBERS_ROLE_ID = '106465861476319232';

function search(text: string) {
    const searchUrl = `https://www.googleapis.com/customsearch/v1?q=${encodeURIComponent(text)}&cx=015370027863181820724%3A1ykhdit5tec&key=${process.env.GOOGLE_API_KEY}`;
    return axios(searchUrl)
        .catch(error => {
            console.error('Search failed', error && error.response);
        })
        .then((response: any) => {
            const results = response.data.items.slice(0, 5);

            let content = '';
            results.forEach((item: any) => {
                const title = item.title.replace(' - The SCP Foundation', '');
                content += `- [${title}](${item.link})\n`;
            });

            const embed = {
                color: 16098851,
                title: 'Результаты поиска',
                description: content
            };

            return {embed};
        })
        .catch(error => {
            console.error('Unhandled error', error);
        });
}

vega.on('ready', () => {
    log('VEGA is ready');
});

vega.on('message', (message: any) => {
    const match = COMMAND_REGEXP.exec(message.content);
    const command = match && match[1];
    const content = message.content.split(' ').slice(1).join(' ');

    switch (command) {
        case 'ping':
            message.channel.send('pong');
            break;
        case 'beep':
            message.channel.send('boop');
            break;
        case 'transfer':
            const allowedChannel = [DEV_CHANNEL_ID, STAFF_CHANNEL_ID].includes(message.channel.id);
            const pageNameMatch = PAGE_NAME_REGEXP.exec(content);
            const pageName = pageNameMatch && pageNameMatch[1];
            if (allowedChannel && pageName) {
                transferPage(pageName.toLowerCase(), message);
            }
            break;
        case 's':
            if (message.member.roles.has(MEMBERS_ROLE_ID)) {
                search(content).then(result => {
                    message.channel.send(result);
                })
                    .catch(e => console.error(e));
            }
            break;
    }
});

vega.on('error', (error: any) => {
    console.error('Error event', error);
});

vega.login(token);
