import {Request, Response} from 'express';
import BanRecord from '../../models/ban-record';

export default async (req: Request, res: Response) => {
    if (req.user.roles.intBanRecordsWriter) {
        const banRecord = BanRecord.new(req.body);
        banRecord.addedBy = req.user.id;
        const errors = await banRecord.validate();
        if (errors.length) {
            res.status(400).send({
                error: 'Record validation error',
                details: errors.map(e => ({property: e.property, constraints: e.constraints}))
            });
        } else {
            const result = await banRecord.save();
            res.send({result: 'Record saved', uuid: result.uuid});
        }
    } else {
        res.status(403).send({error: 'Access denied'});
    }
};
