import {Request, Response} from 'express';
import AccessToken from '../../models/access-token';
import {reportError} from '../../core/utils';
import BanRecord, {DISCORD_ID_REG} from '../../models/ban-record';

export default async (req: Request, res: Response) => {
    if (req.user.roles.intBanRecordsReader) {
        const discordId = req.query.discordId;
        if (discordId) {
            if (DISCORD_ID_REG.test(discordId)) {
                const records = await BanRecord.getByDiscordId(discordId);
                res.send({records});
            } else {
                res.status(400).send({error: 'Incorrect discordId format'});
            }
        } else {
            const records = await BanRecord.getAll();
            res.send({records});
        }
    } else {
        res.status(403).send({error: 'Access denied'});
    }
};
