import db from '../core/db';
import * as pgPromise from 'pg-promise';
import {Request, Response} from 'express';
import QueryResultError = pgPromise.errors.QueryResultError;

const uuidv4: () => string = require('uuid/v4');

export default class AccessToken {
    static async findByToken(token: string) {
        try {
            return await db.one(`
                SELECT * FROM access_tokens WHERE token = $(token);
            `, {token})
        } catch (error) {
            if (error instanceof QueryResultError) {
                return null;
            } else {
                throw error;
            }
        }
    }

    static generateToken() {
        return (uuidv4() + uuidv4()).replace(/-/g, '');
    }

    static async ensureAuth(req: Request, res: Response, role: string, cb: Function) {
        if (!req.token) {
            return res.status(401).send({error: 'Unauthorized'});
        }
        const accessToken = await AccessToken.findByToken(req.token);
        if (accessToken && accessToken.roles[role]) {
            cb();
        } else {
            res.status(403).send({error: 'Access denied'});
        }
    }
}

