'use strict';

import {Express, Router, Request, Response, NextFunction} from 'express';

type Route = {
    path: string,
    name: string,
    method: 'get' | 'post' | 'options'
};

const routes = [
    {
        name: 'main',
        path: '/'
    },
    {
        name: 'ping',
        path: '/ping'
    },
    {
        name: 'wikidot/random-page',
        path: '/wikidot_random_page'
    },
    {
        name: 'wikidot/api/random-page',
        path: '/api/random_page'
    },
    {
        name: 'wikidot/api/random-page',
        path: '/api/wikidot_random_page'
    },
    {
        name: 'wikidot/api/tags-list',
        path: '/_api/wikidot_tags_search/list'
    },
    {
        name: 'wikidot/api/tags-search',
        path: '/_api/wikidot_tags_search/find'
    },
    {
        name: 'wikidot/api/untranslated-list',
        path: '/_api/wanted_translations/list'
    },
    {
        name: 'wikidot/interwiki',
        path: '/interwiki/:wiki_name'
    },
    {
        name: 'int/ban-records-list',
        path: '/api/private/ban-records'
    },
    {
        name: 'int/ban-records-create',
        path: '/api/private/ban-records',
        method: 'post'
    }
];

export default function initRoutes(app: Express) {
    routes.forEach((route: Route) => {
        const method = route.method || 'get';
        const routeMiddleware: ExpressMiddleware[] = [];
        const routeHandler = require(`./controllers/${route.name}`).default;

        app[method](route.path, routeMiddleware, (req: Request, res: Response, next: NextFunction) => {
            Promise.resolve(routeHandler(req, res)).catch(next);
        });
    });
};
