"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Discord = require("discord.js");
const utils_1 = require("../core/utils");
const wikidot_page_1 = require("../models/wikidot-page");
const pages_transferer_1 = require("./pages-transferer");
const axios_1 = require("axios");
const vega = new Discord.Client();
const token = process.env.DISCORD_BOT_TOKEN;
const COMMAND_REGEXP = /^[\/!](\w+)/;
const DEV_CHANNEL_ID = '402913158127288321';
const STAFF_CHANNEL_ID = '363739114895441921';
const MEMBERS_ROLE_ID = '106465861476319232';
function search(text) {
    const searchUrl = `https://www.googleapis.com/customsearch/v1?q=${encodeURIComponent(text)}&cx=015370027863181820724%3A1ykhdit5tec&key=${process.env.GOOGLE_API_KEY}`;
    return axios_1.default(searchUrl)
        .catch(error => {
        console.error('Search failed', error && error.response);
    })
        .then((response) => {
        const results = response.data.items.slice(0, 5);
        let content = '';
        results.forEach((item) => {
            const title = item.title.replace(' - The SCP Foundation', '');
            content += `- [${title}](${item.link})\n`;
        });
        const embed = {
            color: 16098851,
            title: 'Результаты поиска',
            description: content
        };
        return { embed };
    })
        .catch(error => {
        console.error('Unhandled error', error);
    });
}
vega.on('ready', () => {
    utils_1.log('VEGA is ready');
});
vega.on('message', (message) => {
    const match = COMMAND_REGEXP.exec(message.content);
    const command = match && match[1];
    const content = message.content.split(' ').slice(1).join(' ');
    switch (command) {
        case 'ping':
            message.channel.send('pong');
            break;
        case 'beep':
            message.channel.send('boop');
            break;
        case 'transfer':
            const allowedChannel = [DEV_CHANNEL_ID, STAFF_CHANNEL_ID].includes(message.channel.id);
            const pageNameMatch = wikidot_page_1.PAGE_NAME_REGEXP.exec(content);
            const pageName = pageNameMatch && pageNameMatch[1];
            if (allowedChannel && pageName) {
                pages_transferer_1.default(pageName.toLowerCase(), message);
            }
            break;
        case 's':
            if (message.member.roles.has(MEMBERS_ROLE_ID)) {
                search(content).then(result => {
                    message.channel.send(result);
                })
                    .catch(e => console.error(e));
            }
            break;
    }
});
vega.on('error', (error) => {
    console.error('Error event', error);
});
vega.login(token);
//# sourceMappingURL=vega.js.map