"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("reflect-metadata");
const dotenv = require("dotenv");
dotenv.config();
const cluster = require("cluster");
const os_1 = require("os");
const console_1 = require("./components/console");
const express_1 = require("./core/express");
const worker_1 = require("./core/worker");
const schedule_1 = require("./schedule");
const tasks_executer_1 = require("./components/tasks-executer");
const utils_1 = require("./core/utils");
const action = process.argv[2] || 'server';
switch (action) {
    case 'server':
        runServer();
        break;
    case 'console':
        console_1.default();
        break;
    case 'execute':
        tasks_executer_1.default(process.argv[3], process.argv.slice(4));
        break;
    case 'vega':
        runVega();
        break;
    case 'worker':
        worker_1.default();
        break;
}
function runServer() {
    if (process.env.NODE_ENV === 'production' && cluster.isMaster) {
        schedule_1.default();
        const cpuCount = os_1.cpus().length;
        console.log(`Deploying ${cpuCount} http workers`);
        for (let i = 0; i < cpuCount; i += 1) {
            cluster.fork();
        }
    }
    else {
        const port = Number(process.env.PORT) || 4444;
        const listen = express_1.default();
        listen(port);
        console.log(`Worker is listening`);
    }
}
function runVega() {
    utils_1.log('Starting the VEGA server');
    require('./components/vega');
}
//# sourceMappingURL=index.js.map