"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const db_1 = require("../core/db");
const pgPromise = require("pg-promise");
var QueryResultError = pgPromise.errors.QueryResultError;
const uuidv4 = require('uuid/v4');
class AccessToken {
    static async findByToken(token) {
        try {
            return await db_1.default.one(`
                SELECT * FROM access_tokens WHERE token = $(token);
            `, { token });
        }
        catch (error) {
            if (error instanceof QueryResultError) {
                return null;
            }
            else {
                throw error;
            }
        }
    }
    static generateToken() {
        return (uuidv4() + uuidv4()).replace(/-/g, '');
    }
    static async ensureAuth(req, res, role, cb) {
        if (!req.token) {
            return res.status(401).send({ error: 'Unauthorized' });
        }
        const accessToken = await AccessToken.findByToken(req.token);
        if (accessToken && accessToken.roles[role]) {
            cb();
        }
        else {
            res.status(403).send({ error: 'Access denied' });
        }
    }
}
exports.default = AccessToken;
//# sourceMappingURL=access-token.js.map